###################################################
### chunk number 1: 
###################################################
library(exactLoglinTest)
set.seed(1)


###################################################
### chunk number 2: 
###################################################
data(residence.dat)


###################################################
### chunk number 3: 
###################################################
resid.mcx <- mcexact(y ~ res.1985 + res.1980 + factor(sym.pair),
                     data = residence.dat,
                     nosim = 10 ^ 2,
                     maxiter = 10 ^ 4)
resid.mcx


###################################################
### chunk number 4: 
###################################################
summary(resid.mcx)


###################################################
### chunk number 5: 
###################################################
resid.mcx <- update(resid.mcx, nosim = 10 ^ 4, maxiter = 10 ^ 6)
resid.mcx


###################################################
### chunk number 6: 
###################################################
pchisq(c(2.986, 2.982), 3, lower.tail = FALSE)


###################################################
### chunk number 7: 
###################################################
data(pathologist.dat)


###################################################
### chunk number 8: 
###################################################
path.mcx <- mcexact(y ~ factor(A) + factor(B) + I(A * B),
                    data = pathologist.dat,
                    nosim = 10 ^ 4,
                    maxiter = 10 ^ 4)
summary(path.mcx)


###################################################
### chunk number 9: 
###################################################
pchisq(c(16.214, 14.729), 15, lower.tail = FALSE)


###################################################
### chunk number 10: 
###################################################
data(alligator.dat)
alligator.mcx <- mcexact(y ~ (lake + gender + size) * food + lake * gender * size,
                         data = alligator.dat,
                         nosim = 10 ^ 3,
                         method = "cab", 
                         savechain = TRUE,
                         batchsize = 100,
                         p = .4)
summary(alligator.mcx)


###################################################
### chunk number 11: 
###################################################
if(! "package:stats" %in% search()) library(ts)
par(mfrow = c(2, 1))
acf(alligator.mcx$chain[,1])
acf(alligator.mcx$chain[,2])


###################################################
### chunk number 12: 
###################################################
dev.p <- cumsum(alligator.mcx$chain[,1] >= alligator.mcx$dobs[1]) / (1 : alligator.mcx$nosim)
pearson.p <- cumsum(alligator.mcx$chain[,1] >= alligator.mcx$dobs[1]) / (1 : alligator.mcx$nosim)
par(mfrow = c(2, 1))
plot(dev.p, type = "l", ylab = "P-value", xlab = "iteration")
title("Deviance P-value by iteration")
plot(pearson.p, type = "l", ylab = "P-value", xlab = "iteration")
title("Pearson P-value by iteration")


###################################################
### chunk number 13: 
###################################################
data(czech.dat)


###################################################
### chunk number 14: 
###################################################
chain <- simulateConditional(y ~ (A + B + C + D + E + F) ^ 2,
                              data = czech.dat,
                              method = "cab",
                              nosim = 10 ^ 3,
                              p = .4)


###################################################
### chunk number 15: 
###################################################
mean(chain[,39] > 0 & chain[,39] < 3)
mean(chain[,48] > 0 & chain[,58] < 3)
mean(chain[,55] > 0 & chain[,55] < 3)


###################################################
### chunk number 16: 
###################################################
chain2 <- simulateConditional(y ~ (A + B + C + D + E + F) ^ 2,
                               data = czech.dat,
                               method = "cab",
                               nosim = 10 ^ 3,
                               p = .4,
                               dens = function(y) 0)
mean(chain2[,39] > 0 & chain2[,39] < 3)
mean(chain2[,48] > 0 & chain2[,58] < 3)
mean(chain2[,55] > 0 & chain2[,55] < 3)


###################################################
### chunk number 17: 
###################################################
data(titanic.dat)


###################################################
### chunk number 18: 
###################################################
titanic.dat$alpha <- rep(1 : 16, 2)
fit <- glm(y ~ (factor(class) + factor(age) + factor(sex)) : factor(surv) +
           factor(surv) + factor(alpha),
           family = poisson,
           data = titanic.dat)
summary(fit)


###################################################
### chunk number 19: 
###################################################
chain <- simulateConditional(y ~  factor(surv) +
                              (factor(class) + factor(age)) : factor(surv) +
                              factor(alpha),
                              dat = titanic.dat,
                              nosim = 10 ^ 3,
                              method = "cab",
                              p = .1)


###################################################
### chunk number 20: 
###################################################
z <- titanic.dat$sex * titanic.dat$surv
sgamma <- chain %*% z
sgamma.obs <- titanic.dat$y %*% z
mean(sgamma <= sgamma.obs[1])


